# -*- coding: UTF-8 -*-
#
#  Config.py : Manage configuration file
#  Copyright (C) 2007 Mertens Florent <flomertens@gmail.com>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import os
import pwd
import logging
import ConfigParser
from config import CONF_FILE
from Utility import get_user

# Default configuration :

general = {
"backend"      : "auto" ,
"fstab_naming" : "auto"
}

categorie = {
"General"         : general
} 


class Config(ConfigParser.SafeConfigParser) :

    def __init__(self) :
    
        ConfigParser.SafeConfigParser.__init__(self)
        try :
            self.read_config()
        except ConfigParser.ParsingError :
            logging.warning("Parsing error while loading conf file. Using default configuration...")
        for section in categorie.keys() :
            if not self.has_section(section) :
                self.add_section(section)
            for option in categorie[section].keys() :
                if not self.has_option(section,option) :
                    self.set(section,option,categorie[section][option])   
        self.apply_change()
    
    def set(self, section, option, value) :
    
        ConfigParser.SafeConfigParser.set(self, section, option, str(value))
        self.apply_change()
        
    def set_default(self, section, option) :
    
        ConfigParser.SafeConfigParser.set(self, section, option, categorie[section][option])
        self.apply_change()
        return ConfigParser.SafeConfigParser.get(self, section, option)
        
    def read_config(self) :

        self.root_config = pwd.getpwuid(0).pw_dir + CONF_FILE
        if not self.root_config in self.read(self.root_config) :
            conffile = open(self.root_config, "w")
            conffile.close()
        
    def apply_change(self) :
    
        conffile = open(self.root_config, "w")
        self.write(conffile)
        conffile.close()
        self.read(self.root_config)


